import { RangeValue, Range, RangeSet } from "@codemirror/state";
import { Direction } from "./bidi";
import { Attrs } from "./attributes";
import { EditorView } from "./editorview";
import { Rect } from "./dom";
interface MarkDecorationSpec {
    inclusive?: boolean;
    inclusiveStart?: boolean;
    inclusiveEnd?: boolean;
    attributes?: {
        [key: string]: string;
    };
    class?: string;
    tagName?: string;
    bidiIsolate?: Direction;
    [other: string]: any;
}
interface WidgetDecorationSpec {
    widget: WidgetType;
    side?: number;
    inlineOrder?: boolean;
    block?: boolean;
    [other: string]: any;
}
interface ReplaceDecorationSpec {
    widget?: WidgetType;
    inclusive?: boolean;
    inclusiveStart?: boolean;
    inclusiveEnd?: boolean;
    block?: boolean;
    [other: string]: any;
}
interface LineDecorationSpec {
    attributes?: {
        [key: string]: string;
    };
    class?: string;
    [other: string]: any;
}
export declare abstract class WidgetType {
    abstract toDOM(view: EditorView): HTMLElement;
    eq(widget: WidgetType): boolean;
    updateDOM(dom: HTMLElement, view: EditorView): boolean;
    compare(other: WidgetType): boolean;
    get estimatedHeight(): number;
    get lineBreaks(): number;
    ignoreEvent(event: Event): boolean;
    coordsAt(dom: HTMLElement, pos: number, side: number): Rect | null;
    get isHidden(): boolean;
    destroy(dom: HTMLElement): void;
}
export declare type DecorationSet = RangeSet<Decoration>;
export declare enum BlockType {
    Text = 0,
    WidgetBefore = 1,
    WidgetAfter = 2,
    WidgetRange = 3
}
export declare abstract class Decoration extends RangeValue {
    readonly startSide: number;
    readonly endSide: number;
    readonly widget: WidgetType | null;
    readonly spec: any;
    protected constructor(startSide: number, endSide: number, widget: WidgetType | null, spec: any);
    point: boolean;
    get heightRelevant(): boolean;
    abstract eq(other: Decoration): boolean;
    static mark(spec: MarkDecorationSpec): Decoration;
    static widget(spec: WidgetDecorationSpec): Decoration;
    static replace(spec: ReplaceDecorationSpec): Decoration;
    static line(spec: LineDecorationSpec): Decoration;
    static set(of: Range<Decoration> | readonly Range<Decoration>[], sort?: boolean): DecorationSet;
    static none: DecorationSet;
    hasHeight(): boolean;
}
export declare class MarkDecoration extends Decoration {
    tagName: string;
    class: string;
    attrs: Attrs | null;
    constructor(spec: MarkDecorationSpec);
    eq(other: Decoration): boolean;
    range(from: number, to?: number): Range<this>;
}
export declare class LineDecoration extends Decoration {
    constructor(spec: LineDecorationSpec);
    eq(other: Decoration): boolean;
    range(from: number, to?: number): Range<this>;
}
export declare class PointDecoration extends Decoration {
    block: boolean;
    readonly isReplace: boolean;
    constructor(spec: any, startSide: number, endSide: number, block: boolean, widget: WidgetType | null, isReplace: boolean);
    get type(): BlockType.WidgetBefore | BlockType.WidgetAfter | BlockType.WidgetRange;
    get heightRelevant(): boolean;
    eq(other: Decoration): boolean;
    range(from: number, to?: number): Range<this>;
}
export declare function addRange(from: number, to: number, ranges: number[], margin?: number): void;
export {};
