import { EditorState, Transaction, ChangeSet, ChangeDesc, Facet, StateEffect, Extension, SelectionRange, RangeSet } from "@codemirror/state";
import { StyleModule } from "style-mod";
import { DecorationSet } from "./decoration";
import { EditorView, DOMEventHandlers } from "./editorview";
import { Attrs } from "./attributes";
import { Isolate } from "./bidi";
import { Rect, ScrollStrategy } from "./dom";
import { MakeSelectionStyle } from "./input";
export declare type Command = (target: EditorView) => boolean;
export declare const clickAddsSelectionRange: Facet<(event: MouseEvent) => boolean, readonly ((event: MouseEvent) => boolean)[]>;
export declare const dragMovesSelection: Facet<(event: MouseEvent) => boolean, readonly ((event: MouseEvent) => boolean)[]>;
export declare const mouseSelectionStyle: Facet<MakeSelectionStyle, readonly MakeSelectionStyle[]>;
export declare const exceptionSink: Facet<(exception: any) => void, readonly ((exception: any) => void)[]>;
export declare const updateListener: Facet<(update: ViewUpdate) => void, readonly ((update: ViewUpdate) => void)[]>;
export declare const inputHandler: Facet<(view: EditorView, from: number, to: number, text: string, insert: () => Transaction) => boolean, readonly ((view: EditorView, from: number, to: number, text: string, insert: () => Transaction) => boolean)[]>;
export declare const focusChangeEffect: Facet<(state: EditorState, focusing: boolean) => StateEffect<any> | null, readonly ((state: EditorState, focusing: boolean) => StateEffect<any> | null)[]>;
export declare const perLineTextDirection: Facet<boolean, boolean>;
export declare const nativeSelectionHidden: Facet<boolean, boolean>;
export declare class ScrollTarget {
    readonly range: SelectionRange;
    readonly y: ScrollStrategy;
    readonly x: ScrollStrategy;
    readonly yMargin: number;
    readonly xMargin: number;
    constructor(range: SelectionRange, y?: ScrollStrategy, x?: ScrollStrategy, yMargin?: number, xMargin?: number);
    map(changes: ChangeDesc): ScrollTarget;
}
export declare const scrollIntoView: import("@codemirror/state").StateEffectType<ScrollTarget>;
export declare function logException(state: EditorState, exception: any, context?: string): void;
export declare const editable: Facet<boolean, boolean>;
export interface PluginValue extends Object {
    update?(update: ViewUpdate): void;
    destroy?(): void;
}
export declare const viewPlugin: Facet<ViewPlugin<any>, readonly ViewPlugin<any>[]>;
export interface PluginSpec<V extends PluginValue> {
    eventHandlers?: DOMEventHandlers<V>;
    provide?: (plugin: ViewPlugin<V>) => Extension;
    decorations?: (value: V) => DecorationSet;
}
export declare class ViewPlugin<V extends PluginValue> {
    readonly id: number;
    readonly create: (view: EditorView) => V;
    readonly domEventHandlers: DOMEventHandlers<V> | undefined;
    extension: Extension;
    private constructor();
    static define<V extends PluginValue>(create: (view: EditorView) => V, spec?: PluginSpec<V>): ViewPlugin<V>;
    static fromClass<V extends PluginValue>(cls: {
        new (view: EditorView): V;
    }, spec?: PluginSpec<V>): ViewPlugin<V>;
}
export declare class PluginInstance {
    spec: ViewPlugin<any> | null;
    mustUpdate: ViewUpdate | null;
    value: PluginValue | null;
    constructor(spec: ViewPlugin<any> | null);
    update(view: EditorView): this;
    destroy(view: EditorView): void;
    deactivate(): void;
}
export interface MeasureRequest<T> {
    read(view: EditorView): T;
    write?(measure: T, view: EditorView): void;
    key?: any;
}
export declare type AttrSource = Attrs | ((view: EditorView) => Attrs | null);
export declare const editorAttributes: Facet<AttrSource, readonly AttrSource[]>;
export declare const contentAttributes: Facet<AttrSource, readonly AttrSource[]>;
export declare const decorations: Facet<DecorationSet | ((view: EditorView) => DecorationSet), readonly (DecorationSet | ((view: EditorView) => DecorationSet))[]>;
export declare const atomicRanges: Facet<(view: EditorView) => RangeSet<any>, readonly ((view: EditorView) => RangeSet<any>)[]>;
export declare const bidiIsolatedRanges: Facet<DecorationSet | ((view: EditorView) => DecorationSet), readonly (DecorationSet | ((view: EditorView) => DecorationSet))[]>;
export declare function getIsolatedRanges(view: EditorView, from: number, to: number): readonly Isolate[];
export declare const scrollMargins: Facet<(view: EditorView) => Partial<Rect> | null, readonly ((view: EditorView) => Partial<Rect> | null)[]>;
export declare function getScrollMargins(view: EditorView): {
    left: number;
    right: number;
    top: number;
    bottom: number;
};
export declare const styleModule: Facet<StyleModule, readonly StyleModule[]>;
export declare const enum UpdateFlag {
    Focus = 1,
    Height = 2,
    Viewport = 4,
    Geometry = 8
}
export declare class ChangedRange {
    readonly fromA: number;
    readonly toA: number;
    readonly fromB: number;
    readonly toB: number;
    constructor(fromA: number, toA: number, fromB: number, toB: number);
    join(other: ChangedRange): ChangedRange;
    addToSet(set: ChangedRange[]): ChangedRange[];
    static extendWithRanges(diff: readonly ChangedRange[], ranges: number[]): readonly ChangedRange[];
}
export declare class ViewUpdate {
    readonly view: EditorView;
    readonly state: EditorState;
    readonly transactions: readonly Transaction[];
    readonly changes: ChangeSet;
    readonly startState: EditorState;
    flags: number;
    changedRanges: readonly ChangedRange[];
    private constructor();
    static create(view: EditorView, state: EditorState, transactions: readonly Transaction[]): ViewUpdate;
    get viewportChanged(): boolean;
    get heightChanged(): boolean;
    get geometryChanged(): boolean;
    get focusChanged(): boolean;
    get docChanged(): boolean;
    get selectionSet(): boolean;
    get empty(): boolean;
}
