import { Facet, Extension, EditorState, RangeValue, RangeSet } from "@codemirror/state";
import { EditorView } from "./editorview";
import { ViewUpdate } from "./extension";
import { WidgetType } from "./decoration";
import { BlockInfo } from "./heightmap";
export declare abstract class GutterMarker extends RangeValue {
    compare(other: GutterMarker): boolean;
    eq(other: GutterMarker): boolean;
    toDOM?(view: EditorView): Node;
    elementClass: string;
    destroy(dom: Node): void;
}
export declare const gutterLineClass: Facet<RangeSet<GutterMarker>, readonly RangeSet<GutterMarker>[]>;
declare type Handlers = {
    [event: string]: (view: EditorView, line: BlockInfo, event: Event) => boolean;
};
interface GutterConfig {
    class?: string;
    renderEmptyElements?: boolean;
    markers?: (view: EditorView) => (RangeSet<GutterMarker> | readonly RangeSet<GutterMarker>[]);
    lineMarker?: (view: EditorView, line: BlockInfo, otherMarkers: readonly GutterMarker[]) => GutterMarker | null;
    widgetMarker?: (view: EditorView, widget: WidgetType, block: BlockInfo) => GutterMarker | null;
    lineMarkerChange?: null | ((update: ViewUpdate) => boolean);
    initialSpacer?: null | ((view: EditorView) => GutterMarker);
    updateSpacer?: null | ((spacer: GutterMarker, update: ViewUpdate) => GutterMarker);
    domEventHandlers?: Handlers;
}
export declare function gutter(config: GutterConfig): Extension;
export declare function gutters(config?: {
    fixed?: boolean;
}): Extension;
interface LineNumberConfig {
    formatNumber?: (lineNo: number, state: EditorState) => string;
    domEventHandlers?: Handlers;
}
export declare const lineNumberMarkers: Facet<RangeSet<GutterMarker>, readonly RangeSet<GutterMarker>[]>;
export declare function lineNumbers(config?: LineNumberConfig): Extension;
export declare function highlightActiveLineGutter(): Extension;
export {};
