import { Text as DocText } from "@codemirror/state";
import { ContentView, DOMPos } from "./contentview";
import { WidgetType, MarkDecoration } from "./decoration";
import { Rect } from "./dom";
import { EditorView } from "./editorview";
export declare class TextView extends ContentView {
    text: string;
    children: ContentView[];
    dom: Text | null;
    constructor(text: string);
    get length(): number;
    createDOM(textDOM?: Node): void;
    sync(view: EditorView, track?: {
        node: Node;
        written: boolean;
    }): void;
    reuseDOM(dom: Node): void;
    merge(from: number, to: number, source: ContentView | null): boolean;
    split(from: number): TextView;
    localPosFromDOM(node: Node, offset: number): number;
    domAtPos(pos: number): DOMPos;
    domBoundsAround(_from: number, _to: number, offset: number): {
        from: number;
        to: number;
        startDOM: Text;
        endDOM: ChildNode;
    };
    coordsAt(pos: number, side: number): Rect | null;
}
export declare class MarkView extends ContentView {
    readonly mark: MarkDecoration;
    children: ContentView[];
    length: number;
    dom: HTMLElement | null;
    constructor(mark: MarkDecoration, children?: ContentView[], length?: number);
    setAttrs(dom: HTMLElement): HTMLElement;
    canReuseDOM(other: ContentView): boolean;
    reuseDOM(node: Node): void;
    sync(view: EditorView, track?: {
        node: Node;
        written: boolean;
    }): void;
    merge(from: number, to: number, source: ContentView | null, _hasStart: boolean, openStart: number, openEnd: number): boolean;
    split(from: number): MarkView;
    domAtPos(pos: number): DOMPos;
    coordsAt(pos: number, side: number): Rect | null;
}
export declare class WidgetView extends ContentView {
    widget: WidgetType;
    length: number;
    readonly side: number;
    children: ContentView[];
    dom: HTMLElement | null;
    prevWidget: WidgetType | null;
    static create(widget: WidgetType, length: number, side: number): WidgetView;
    constructor(widget: WidgetType, length: number, side: number);
    split(from: number): WidgetView;
    sync(view: EditorView): void;
    getSide(): number;
    merge(from: number, to: number, source: ContentView | null, hasStart: boolean, openStart: number, openEnd: number): boolean;
    become(other: ContentView): boolean;
    ignoreMutation(): boolean;
    ignoreEvent(event: Event): boolean;
    get overrideDOMText(): DocText | null;
    domAtPos(pos: number): DOMPos;
    domBoundsAround(): any;
    coordsAt(pos: number, side: number): Rect | null;
    get isEditable(): boolean;
    get isWidget(): boolean;
    get isHidden(): boolean;
    destroy(): void;
}
export declare class WidgetBufferView extends ContentView {
    readonly side: number;
    children: ContentView[];
    dom: HTMLElement | null;
    constructor(side: number);
    get length(): number;
    merge(): boolean;
    become(other: ContentView): boolean;
    split(): WidgetBufferView;
    sync(): void;
    getSide(): number;
    domAtPos(pos: number): DOMPos;
    localPosFromDOM(): number;
    domBoundsAround(): any;
    coordsAt(pos: number): Rect | null;
    get overrideDOMText(): DocText;
    get isHidden(): boolean;
}
export declare function inlineDOMAtPos(parent: ContentView, pos: number): DOMPos;
export declare function joinInlineInto(parent: ContentView, view: ContentView, open: number): void;
export declare function coordsInChildren(view: ContentView, pos: number, side: number): Rect | null;
