import { EditorSelection, EditorState, SelectionRange, RangeSet } from "@codemirror/state";
import { EditorView, DOMEventHandlers } from "./editorview";
import { ViewUpdate, PluginValue, PluginInstance } from "./extension";
export declare class InputState {
    lastKeyCode: number;
    lastKeyTime: number;
    lastTouchTime: number;
    lastFocusTime: number;
    lastScrollTop: number;
    lastScrollLeft: number;
    chromeScrollHack: number;
    pendingIOSKey: undefined | {
        key: string;
        keyCode: number;
    };
    lastSelectionOrigin: string | null;
    lastSelectionTime: number;
    lastEscPress: number;
    lastContextMenu: number;
    scrollHandlers: ((event: Event) => boolean | void)[];
    registeredEvents: string[];
    customHandlers: {
        plugin: PluginValue;
        handlers: DOMEventHandlers<any>;
    }[];
    composing: number;
    compositionFirstChange: boolean | null;
    compositionEndedAt: number;
    compositionPendingKey: boolean;
    compositionPendingChange: boolean;
    mouseSelection: MouseSelection | null;
    notifiedFocused: boolean;
    setSelectionOrigin(origin: string): void;
    constructor(view: EditorView);
    ensureHandlers(view: EditorView, plugins: readonly PluginInstance[]): void;
    runCustomHandlers(type: string, view: EditorView, event: Event): boolean;
    runScrollHandlers(view: EditorView, event: Event): void;
    keydown(view: EditorView, event: KeyboardEvent): boolean;
    flushIOSKey(view: EditorView): boolean;
    ignoreDuringComposition(event: Event): boolean;
    mustFlushObserver(event: Event): boolean;
    startMouseSelection(mouseSelection: MouseSelection): void;
    update(update: ViewUpdate): void;
    destroy(): void;
}
export declare const modifierCodes: number[];
export interface MouseSelectionStyle {
    get: (curEvent: MouseEvent, extend: boolean, multiple: boolean) => EditorSelection;
    update: (update: ViewUpdate) => boolean | void;
}
export declare type MakeSelectionStyle = (view: EditorView, event: MouseEvent) => MouseSelectionStyle | null;
declare class MouseSelection {
    private view;
    private startEvent;
    private style;
    private mustSelect;
    dragging: null | false | SelectionRange;
    extend: boolean;
    multiple: boolean;
    lastEvent: MouseEvent;
    scrollParent: HTMLElement | null;
    scrollSpeed: {
        x: number;
        y: number;
    };
    scrolling: number;
    atoms: readonly RangeSet<any>[];
    constructor(view: EditorView, startEvent: MouseEvent, style: MouseSelectionStyle, mustSelect: boolean);
    start(event: MouseEvent): void;
    move(event: MouseEvent): void;
    up(event: MouseEvent): void;
    destroy(): void;
    setScrollSpeed(sx: number, sy: number): void;
    scroll(): void;
    skipAtoms(sel: EditorSelection): EditorSelection;
    select(event: MouseEvent): void;
    update(update: ViewUpdate): void;
}
export declare const isFocusChange: import("@codemirror/state").AnnotationType<boolean>;
export declare function focusChangeTransaction(state: EditorState, focus: boolean): import("@codemirror/state").Transaction;
export {};
