import { EditorState, ChangeSet, ChangeDesc } from "@codemirror/state";
import { Rect } from "./dom";
import { HeightMap, HeightOracle, BlockInfo } from "./heightmap";
import { ViewUpdate, UpdateFlag, ScrollTarget } from "./extension";
import { Decoration, DecorationSet } from "./decoration";
import { EditorView } from "./editorview";
import { Direction } from "./bidi";
export declare class LineGap {
    readonly from: number;
    readonly to: number;
    readonly size: number;
    constructor(from: number, to: number, size: number);
    static same(a: readonly LineGap[], b: readonly LineGap[]): boolean;
    draw(viewState: ViewState, wrapping: boolean): import("@codemirror/state").Range<Decoration>;
}
export declare class ViewState {
    state: EditorState;
    pixelViewport: Rect;
    inView: boolean;
    paddingTop: number;
    paddingBottom: number;
    contentDOMWidth: number;
    contentDOMHeight: number;
    editorHeight: number;
    editorWidth: number;
    scrollTop: number;
    scrolledToBottom: boolean;
    scaleX: number;
    scaleY: number;
    scrollAnchorPos: number;
    scrollAnchorHeight: number;
    heightOracle: HeightOracle;
    heightMap: HeightMap;
    scaler: YScaler;
    scrollTarget: ScrollTarget | null;
    printing: boolean;
    mustMeasureContent: boolean;
    stateDeco: readonly DecorationSet[];
    viewportLines: BlockInfo[];
    defaultTextDirection: Direction;
    viewport: Viewport;
    viewports: readonly Viewport[];
    visibleRanges: readonly {
        from: number;
        to: number;
    }[];
    lineGaps: readonly LineGap[];
    lineGapDeco: DecorationSet;
    mustEnforceCursorAssoc: boolean;
    constructor(state: EditorState);
    updateForViewport(): void;
    updateViewportLines(): void;
    update(update: ViewUpdate, scrollTarget?: ScrollTarget | null): void;
    measure(view: EditorView): number;
    get visibleTop(): number;
    get visibleBottom(): number;
    getViewport(bias: number, scrollTarget: ScrollTarget | null): Viewport;
    mapViewport(viewport: Viewport, changes: ChangeDesc): Viewport;
    viewportIsAppropriate({ from, to }: Viewport, bias?: number): boolean;
    mapLineGaps(gaps: readonly LineGap[], changes: ChangeSet): any[] | readonly LineGap[];
    ensureLineGaps(current: readonly LineGap[], mayMeasure?: EditorView): LineGap[];
    gapSize(line: BlockInfo, from: number, to: number, structure: LineStructure): number;
    updateLineGaps(gaps: readonly LineGap[]): void;
    computeVisibleRanges(): 0 | UpdateFlag.Viewport;
    lineBlockAt(pos: number): BlockInfo;
    lineBlockAtHeight(height: number): BlockInfo;
    scrollAnchorAt(scrollTop: number): BlockInfo;
    elementAtHeight(height: number): BlockInfo;
    get docHeight(): number;
    get contentHeight(): number;
}
export declare class Viewport {
    readonly from: number;
    readonly to: number;
    constructor(from: number, to: number);
}
declare type LineStructure = {
    total: number;
    ranges: {
        from: number;
        to: number;
    }[];
};
declare type YScaler = {
    toDOM(n: number): number;
    fromDOM(n: number): number;
    scale: number;
};
export {};
